#
# spec file for package re
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global sover   28
%global libname lib%{name}%{sover}
Name:           re
Version:        3.17.0
Release:        1.4
Summary:        Library for real-time communications with async I/O support
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://github.com/baresip/re
Source:         %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
Obsoletes:      librem4 < %{version}

%description
Libre is a library for real-time communications
with async IO support and a complete SIP stack with support for protocols
such as SDP, RTP/RTCP, STUN/TURN/ICE, BFCP, HTTP and DNS Client.

%package -n %{libname}
Summary:        Library for real-time communications with async IO support
Group:          System/Libraries

%description -n %{libname}
Libre is a library for real-time communications
with async I/O support and a complete SIP stack with support for protocols
such as SDP, RTP/RTCP, STUN/TURN/ICE, BFCP, HTTP and DNS Client.

%package devel
Summary:        Development files for libre
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}-%{release}

%description devel
Libre is a portable and generic library for real-time communications
with async I/O support and a complete SIP stack with support for protocols
such as SDP, RTP/RTCP, STUN/TURN/ICE, BFCP, HTTP and DNS Client.

This subpackage contains libraries and header files for developing
applications that want to make use of libre.

%prep
%setup -q

%build
%cmake \
  -DCMAKE_BUILD_TYPE=Release
%cmake_build

%install
%cmake_install
rm -v %{buildroot}/%{_libdir}/libre.a

%ldconfig_scriptlets -n %{libname}

%check
%ctest

%files -n %{libname}
%license LICENSE
%doc CHANGELOG.md README.md
%{_libdir}/libre.so.%{sover}*

%files devel
%license LICENSE
%{_includedir}/re
#%%{_datadir}/re
%{_libdir}/libre.so
%{_libdir}/pkgconfig/libre.pc
%dir %{_libdir}/cmake/libre
%{_libdir}/cmake/libre/libre-config.cmake
%{_libdir}/cmake/libre/libre-targets-release.cmake
%{_libdir}/cmake/libre/libre-targets.cmake
%dir %{_libdir}/cmake/re
%{_libdir}/cmake/re/re-config.cmake

%changelog
* Thu Nov  7 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 3.17.0
  * types: remove old BREAKPOINT macro.
  * dnsc: Fallback to getaddrinfo without any DNS servers.
  * dns/client: return ENOTSUP if no server or not getaddrinfo.
  * conf: add conf_get_float.
  * test: add pktsize to test_h264_packet_base().
  * tls: make tls_verify_handler() static.
  * types: fix clang-tidy warning (gcc bit fields workaround).
* Thu Oct  3 2024 Martin Hauke <mardnh@gmx.de>
- Udpate to version 3.16.0
  Changes:
  * https://github.com/baresip/re/releases/tag/v3.16.0
  * https://github.com/baresip/re/releases/tag/v3.15.0
  * https://github.com/baresip/re/releases/tag/v3.14.0
  * https://github.com/baresip/re/releases/tag/v3.13.0
  * https://github.com/baresip/re/releases/tag/v3.12.0
* Sun Apr 14 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 3.11.0
  Changes:
  * https://github.com/baresip/re/releases/tag/v3.11.0
  * https://github.com/baresip/re/releases/tag/v3.10.0
  * https://github.com/baresip/re/releases/tag/v3.9.0
* Wed Dec 27 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 3.8.0
  Changes:
  * https://github.com/baresip/re/releases/tag/v3.8.0
  * https://github.com/baresip/re/releases/tag/v3.7.0
  * https://github.com/baresip/re/releases/tag/v3.6.2
  * https://github.com/baresip/re/releases/tag/v3.6.1
  * https://github.com/baresip/re/releases/tag/v3.6.0
  * https://github.com/baresip/re/releases/tag/v3.5.1
  * https://github.com/baresip/re/releases/tag/v3.5.0
* Fri Sep  8 2023 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 3.4.0:
  * rtpext: uniform parameter name fixes doxygen warning
  * mk: add rem to doxygen inputs
  * vidmix: allow different pixel format
  * ajb doxygen
  * aes: correct parameters for stub
  * ci/build: fail on cmake and compile warnings
  * fmt: fix format string in fmt_timestamp()
  * hmac,md5,sha: add mbedtls backend
  * test: no need to rewind freshly allocated mbuf
  * httpauth: basic challenge creation and verification functions
  * Fix include of re_thread.h in re_tmr.h
  * btrace: fix WIN32_LEAN_AND_MEAN macro redefine
  * aumix: add record sum handler
  * ci/win: disable x86 testing
  * sipsess: allow UPDATE and INFO in early dialog
  * prefix macro VERSION
  * main: use HAVE_SIGNAL in init.c
  * test: change to ASSERT_XXX macros, remove EXPECT_XXX macros
  * fmt: handy functions for pointer-length objects
  * test: add TWCC test from Chrome 114 packet
  * sipsess/listen: Fix target_refresh_handler
  * ci/mingw: downgrade cmake
  * cmake: fix target include path for subdir projects
* Fri Jul 28 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.3.0:
  Breaking changes:
  * librem is now merged with libre
  Changes:
  * https://github.com/baresip/re/releases/tag/v3.3.0
  * https://github.com/baresip/re/releases/tag/v3.2.0
  * https://github.com/baresip/re/releases/tag/v3.1.0
  * https://github.com/baresip/re/releases/tag/v3.0.0
* Sun Dec 11 2022 Andreas Stieger <andreas.stieger@gmx.de>
- re 2.10.0:
  * h264: add STAP-A
  * h265: add missing NAL types
  * rtpext: move from baresip to re
  * dns: fix dnsc_conf_set memory leak
  * developer visible fixes
* Sun Dec  4 2022 Andreas Stieger <andreas.stieger@gmx.de>
- re 2.9.0:
  * general maintenance and bugfix release
* Sat Oct  1 2022 Martin Hauke <mardnh@gmx.de>
- Update to release 2.8.0
  * No high level changelog provided, see packaged CHANGELOG.md for
    details.
- Use CMake for the build
* Thu Aug 25 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.6.0
  * sip: add RFC 3262, 3311 support
  * bfcp: Add support for TCP transport
* Tue Jun 28 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 2.4.0:
  * No high level changelog provided, see packaged CHANGELOG.md for
    details.
* Sat May 21 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.3.0:
  * network improvements
  * static code analysis fixes
  * aubuf adaptive jitter buffer
  * Support adding CRLs
  * shim: new module
  * new Trice module
  * error corrections and developer visible fixes
  * ToS for video and sip
* Sat Apr 24 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.1
  Added
  * aac: add AAC_STREAMTYPE_AUDIO enum value
  * aac: add AAC_ prefix
  * Video mode param to call_answer(), ua_answer() and
    ua_hold_answer
  * video_stop_display() API function
  * module: add path to module_load() function
  * conf: add conf_configure_buf
  * test: add usage of g711.so module
  * JSON initial codec state command and response
  * account_set_video_codecs() API function
  * net: add fallback dns nameserver
  * gtk: show call_peername in notify title
  * call: Added call_state() API function that returns enum state
    of the call
  * account_set_stun_user() and account_set_stun_pass() API
    functions.
  * API functions account_stun_uri and account_set_stun_uri.
  * ausine: Audio sine wave input module
  * gtk/menu: replace spaces from uri
  * jack: allowing jack client name to be specified in the
    config file
  * snapshot: Add snapshot_send and snapshot_recv commands
  * webrtc_aec: 'extended_filter' config option
  * avfilter: FFmpeg filter graphs integration
  * reg: view proxy expiry value in reg_status
  * account: add parameter rwait for re-register interval
  * call, stream, menu: add cmd to set the direction of video
    stream
  * Added AMRWBENC_PATH env var to amr module module.mk
  Changed
  * Using baresip/re fork now
  * audio: move calculation to audio_jb_current_value
  * avformat: clean up docs
  * gzrtp: update docs
  * account: increased size of audio codec list to 16
  * video: make video_sdp_attr_decode public
  * config: Derive default audio driver from default audio device
  * jack: modifying info message on jack client creation
  * call: when video stream is disabled, stop also video display
  * dtls_srtp: use tls_set_selfsigned_rsa with keysize 2048
  * rst: use a min ptime of 20ms
  * aac: change ptime to 4ms
  Fixed
  * avcodec: fix H.264 interop with Firefox
  * avcodec: call av_hwdevice_ctx_create before if-statement
  * account: use single quote instead of backtick
  * ice: fix segfault in connh #980
  * call: Update call->got_offer when re-INVITE or answer to
    re-INVITE is received
  * config: Allow distribution specific CA trust bundle locations
  * config: Allow distribution specific default audio device
  * mqtt: fix err is never read (found by clang static analyzer)
  * avcodec: fix err is never read (found by clang static analyzer)
  * gtk: notification buttons do not work on Systems #1012
  * gtk: fix dtmf_tone and add tones as feedback #1010
  * pulse: drain pulse buffers before freeing #1016
  * jack: jack_play connect all physical ports #1028
  * Makefile: do not try to install modules if build is static
  * gzrtp: media_alloc function is missing #1034 #1022
  * call: when updating video, check if video stream has been
    disabled #1037
  * amr: fix length check, fixes #1011
  * modules: fix search path for avdevice.h #1043
  * gtk: declare variables C89 style
  * config: init newly added member
  * menu: fix segfault in ua_event_handler #1059 #1061
  * debug_cmd: fix OpenSSL no-deprecated #1065
  * aac: handle missing bitrate parameter in SDP format
  * av1: properly configure encoder
  * call: When terminating outgoing call, terminate also possible
    refer subscription #1082
  * menu: fix segfault in /aubitrate command
  * amr: should check if file (instead of directory) exists
  Removed
  * ice: remove support for ICE-lite
  * ice: remove ice_debug, use log level DEBUG instead
  * ice: make stun server optional
  * config: remove ice_debug option (unused)
  * opengles: remove module (not working) #1079
* Wed Jun 24 2020 Martin Hauke <mardnh@gmx.de>
- Specfile cleanup
* Fri Nov  5 2010 Alfred E. Heggestad <aeh@db.org>
- Initial build
